==> datami_plugin-0.0.2.tar.gz: android/src/main/kotlin/io/skore/datami_plugin/DatamiPlugin.kt <==
package io.skore.datami_plugin

import android.util.Log
import com.datami.smi.SmiSdk
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

class DatamiPlugin(private val channel: MethodChannel) : MethodCallHandler {
    private val TAG = DatamiPlugin::class.java.simpleName

    companion object {
        @JvmStatic
        fun registerWith(registrar: Registrar) {
            val channel = MethodChannel(registrar.messenger(), "datami_plugin")
            channel.setMethodCallHandler(DatamiPlugin(channel))
        }
    }

    override fun onMethodCall(call: MethodCall, result: Result) {
        when (call.method) {
            "initSponsoredData" -> {
//                val smiKey = call.argument<String>("smiKey")
//                if (smiKey.isNullOrBlank()) {
//                    result.error("ERROR", "Invalid smiKey argument", null)
//                    return
//                }
//                val userID = call.argument<String>("userID") ?: ""
//                val appIcon = context.packageManager.getApplicationInfo(context.packageName, PackageManager.GET_META_DATA).icon

//                SmiSdk.initSponsoredData(smiKey, context, userID, appIcon, true, null)
                result.success(0)
            }
            // CALL ONLY ONCE
            "addSdStateChangeListener" -> {
                SmiSdk.addSdStateChangeListener {
                    Log.d(TAG, "onChange")
                    channel.invokeMethod("onSmiStatusChange", it?.sdState?.statusCode ?: 0)
                }
                result.success(0)
            }
            "startSponsoredData" -> {
                SmiSdk.startSponsoredData()
                result.success(0)
            }
            "stopSponsoredData" -> {
                SmiSdk.stopSponsoredData()
                result.success(0)
            }
            else -> result.notImplemented()
        }
    }
}

==> datami_plugin-0.0.10.tar.gz: android/src/main/kotlin/io/skore/datami_plugin/DatamiPlugin.kt <==
package io.skore.datami_plugin

import android.util.Log
import androidx.annotation.NonNull
import com.datami.smi.SmiSdk
import io.flutter.embedding.engine.plugins.FlutterPlugin
import io.flutter.plugin.common.BinaryMessenger
import io.flutter.plugin.common.MethodCall
import io.flutter.plugin.common.MethodChannel
import io.flutter.plugin.common.MethodChannel.MethodCallHandler
import io.flutter.plugin.common.MethodChannel.Result
import io.flutter.plugin.common.PluginRegistry.Registrar

class DatamiPlugin(): FlutterPlugin, MethodCallHandler {
    private var channel: MethodChannel? = null
    private val TAG = DatamiPlugin::class.java.simpleName

    override fun onAttachedToEngine(@NonNull flutterPluginBinding: FlutterPlugin.FlutterPluginBinding) {
        onAttachedToEngine(flutterPluginBinding.binaryMessenger)
    }

    override fun onDetachedFromEngine(binding: FlutterPlugin.FlutterPluginBinding) {
        channel?.setMethodCallHandler(null)
        channel = null
    }

    companion object {
        private var instance: DatamiPlugin? = null

        @JvmStatic
        fun registerWith(registrar: Registrar) {
            if (instance == null) {
                instance = DatamiPlugin().apply {
                    onAttachedToEngine(registrar.messenger());
                };
            }
        }
    }

    fun onAttachedToEngine(binaryMessenger: BinaryMessenger) {
        if (channel == null) {
            channel = MethodChannel(binaryMessenger, "datami_plugin").apply {
                setMethodCallHandler(this@DatamiPlugin)
            }
        }
    }

    override fun onMethodCall(call: MethodCall, result: Result) {
        when (call.method) {
            "initSponsoredData" -> {
//                val smiKey = call.argument<String>("smiKey")
//                if (smiKey.isNullOrBlank()) {
//                    result.error("ERROR", "Invalid smiKey argument", null)
//                    return
//                }
//                val userID = call.argument<String>("userID") ?: ""
//                val appIcon = context.packageManager.getApplicationInfo(context.packageName, PackageManager.GET_META_DATA).icon

//                SmiSdk.initSponsoredData(smiKey, context, userID, appIcon, true, null)
                result.success(0)
            }
            // CALL ONLY ONCE
            "addSdStateChangeListener" -> {
                SmiSdk.addSdStateChangeListener {
                    Log.d(TAG, "onChange")
                    channel?.invokeMethod("onSmiStatusChange", it?.sdState?.statusCode ?: 0)
                }
                result.success(0)
            }
            "startSponsoredData" -> {
                SmiSdk.startSponsoredData()
                result.success(0)
            }
            "stopSponsoredData" -> {
                SmiSdk.stopSponsoredData()
                result.success(0)
            }
            else -> result.notImplemented()
        }
    }
}
